@@ -12,10 +12,9 @@ Created on 15 Dec 2020
 
 import struct
 from datetime import datetime, timedelta
-from math import sqrt, sin, cos, atan2, asin, acos, pi
+from math import sin, cos, pi
 from pyubx2.ubxtypes_core import GNSSLIST, UBX_HDR, NMEA_HDR
 import pyubx2.ubxtypes_core as ubt
-from pyubx2.ubxtypes_core import WGS84_SMAJ_AXIS, WGS84_FLATTENING
 import pyubx2.ubxtypes_configdb as ubcdb
 import pyubx2.exceptions as ube
 
@@ -468,220 +467,19 @@ def hextable(raw: bytes, cols: int = 8) -> str:
     return hextbl
 
 
-def latlon2dms(lat: float, lon: float) -> tuple:
+def cel2cart(elevation: float, azimuth: float) -> tuple:
     """
-    Converts decimal lat/lon tuple to degrees minutes seconds.
+    Convert celestial coordinates (degrees) to Cartesian coordinates.
 
-    :param float lat: lat
-    :param float lon: lon
-    :return: (lat,lon) in d.m.s. format
+    :param float elevation: elevation
+    :param float azimuth: azimuth
+    :return: cartesian x,y coordinates
     :rtype: tuple
     """
 
-    lat = deg2dms(lat, "LA")
-    lon = deg2dms(lon, "LN")
-    return lat, lon
-
-
-def latlon2dmm(lat: float, lon: float) -> tuple:
-    """
-    Converts decimal lat/lon tuple to degrees decimal minutes.
-
-    :param float lat: lat
-    :param float lon: lon
-    :return: (lat,lon) in d.mm.m format
-    :rtype: tuple
-    """
-
-    lat = deg2dmm(lat, "LA")
-    lon = deg2dmm(lon, "LN")
-    return lat, lon
-
-
-def deg2dms(degrees: float, att: str) -> str:
-    """
-    Convert decimal degrees to degrees minutes seconds string
-    e.g. '51°20′45.6″N'
-
-    :param float degrees: degrees
-    :param str att: 'LA' (lat) or 'LN' (lon)
-    :return: degrees as d.m.s formatted string
-    :rtype: str
-
-    """
-
-    try:
-        negative = degrees < 0
-        degrees = abs(degrees)
-        minutes, seconds = divmod(degrees * 3600, 60)
-        degrees, minutes = divmod(minutes, 60)
-        if negative:
-            sfx = "S" if att == "LA" else "W"
-        else:
-            sfx = "N" if att == "LA" else "E"
-        return f"{int(degrees)}\u00b0{int(minutes)}\u2032{round(seconds,5)}\u2033{sfx}"
-    except (TypeError, ValueError):
-        return ""
-
-
-def deg2dmm(degrees: float, att: str) -> str:
-    """
-    Convert decimal degrees to degrees decimal minutes string
-    e.g. '51°20.76′S'.
-
-    :param float degrees: degrees
-    :param str att: 'LA' (lat) or 'LN' (lon)
-    :return: degrees as dm.m formatted string
-    :rtype: str
-
-    """
-
-    try:
-        negative = degrees < 0
-        degrees = abs(degrees)
-        degrees, minutes = divmod(degrees * 60, 60)
-        if negative:
-            sfx = "S" if att == "LA" else "W"
-        else:
-            sfx = "N" if att == "LA" else "E"
-        return f"{int(degrees)}\u00b0{round(minutes,7)}\u2032{sfx}"
-    except (TypeError, ValueError):
-        return ""
-
-
-def ecef2llh(
-    x: float,
-    y: float,
-    z: float,
-    a: float = WGS84_SMAJ_AXIS,
-    f: float = WGS84_FLATTENING,
-) -> tuple:
-    """
-    Convert ECEF coordinates to geodetic (LLH) using Olson algorithm.
-
-    Olson, D. K. (1996). Converting Earth-Centered, Earth-Fixed Coordinates to
-    Geodetic Coordinates. IEEE Transactions on Aerospace and Electronic Systems,
-    32(1), 473-476. https://doi.org/10.1109/7.481290
-
-    :param float x: X coordinate
-    :param float y: Y coordinate
-    :param float z: Z coordinate
-    :param float a: semi-major axis (6378137.0 for WGS84)
-    :param float f: flattening (298.257223563 for WGS84)
-    :return: tuple of (lat, lon, ellipsoidal height in m) as floats
-    :rtype: tuple
-    """
-    # pylint: disable=too-many-locals
-
-    # commented default values are for WGS84 spheroid
-    f = 1 / f
-    e2 = f * (2 - f)  # 6.6943799901377997e-3
-    a1 = a * e2  # 4.2697672707157535e4
-    a2 = a1 * a1  # 1.8230912546075455e9
-    a3 = a1 * e2 / 2  # 1.8230912546075455e9
-    a4 = 2.5 * a2  # 4.5577281365188637e9
-    a5 = a1 + a3  # 4.2840589930055659e4
-    a6 = 1 - e2  # 9.9330562000986220e-1
-    zp = abs(z)
-    w2 = x * x + y * y
-    w = sqrt(w2)
-    z2 = z * z
-    r2 = w2 + z2
-    r = sqrt(r2)
-
-    # algorithm inaccurate near Earth's core
-    # so nominal value returned
-    if r < 100000.0:
-        return 0.0, 0.0, -1.0e7
-
-    lon = atan2(y, x)
-    s2 = z2 / r2
-    c2 = w2 / r2
-    u = a2 / r
-    v = a3 - a4 / r
-    if c2 > 0.3:
-        s = (zp / r) * (1.0 + c2 * (a1 + u + s2 * v) / r)
-        lat = asin(s)
-        ss = s * s
-        c = sqrt(1.0 - ss)
-    else:
-        c = (w / r) * (1.0 - s2 * (a5 - u - c2 * v) / r)
-        lat = acos(c)
-        ss = 1.0 - c * c
-        s = sqrt(ss)
-    g = 1.0 - e2 * ss
-    rg = a / sqrt(g)
-    rf = a6 * rg
-    u = w - rg * c
-    v = zp - rf * s
-    f = c * u + s * v
-    m = c * v - s * u
-    p = m / (rf / g + f)
-    lat = lat + p
-    height = f + m * p / 2.0
-    if z < 0.0:
-        lat = -lat
-
-    lat, lon = [c * 180 / pi for c in (lat, lon)]
-    return lat, lon, height
-
-
-def llh2ecef(
-    lat: float,
-    lon: float,
-    height: float,
-    a: float = WGS84_SMAJ_AXIS,
-    f: float = WGS84_FLATTENING,
-) -> tuple:
-    """
-    Convert geodetic coordinates (LLH) to ECEF.
-
-    :param float lat: lat in degrees
-    :param float lon: lon on degrees
-    :param float height: ellipsoidal height in metres
-    :param float a: semi-major axis (6378137.0 for WGS84)
-    :param float f: flattening (298.257223563 for WGS84)
-    :return: tuple of ECEF (X, Y, Z) as floats
-    :rtype: tuple
-    """
-
-    lat, lon = [c * pi / 180 for c in (lat, lon)]
-
-    f = 1 / f
-    e2 = f * (2 - f)
-    a2 = a**2
-    b2 = a2 * (1 - e2)
-
-    N = a / sqrt(1 - e2 * sin(lat) ** 2)
-    x = (N + height) * cos(lat) * cos(lon)
-    y = (N + height) * cos(lat) * sin(lon)
-    z = ((b2 / a2) * N + height) * sin(lat)
-
-    return x, y, z
-
-
-def haversine(
-    lat1: float,
-    lon1: float,
-    lat2: float,
-    lon2: float,
-    radius: int = WGS84_SMAJ_AXIS / 1000,
-) -> float:
-    """
-    Calculate spherical distance in km between two coordinates using haversine formula.
-
-    :param float lat1: lat1
-    :param float lon1: lon1
-    :param float lat2: lat2
-    :param float lon2: lon2
-    :param float radius: radius in km (Earth = 6378.137 km)
-    :return: spherical distance in km
-    :rtype: float
-    """
-
-    phi1, lambda1, phi2, lambda2 = [c * pi / 180 for c in (lat1, lon1, lat2, lon2)]
-    dist = radius * acos(
-        cos(phi2 - phi1) - cos(phi1) * cos(phi2) * (1 - cos(lambda2 - lambda1))
-    )
-
-    return round(dist, 3)
+    if not (isinstance(elevation, (float, int)) and isinstance(azimuth, (float, int))):
+        return (0, 0)
+    ele, azi = [c * pi / 180 for c in (elevation, azimuth)]
+    x = cos(azi) * cos(ele)
+    y = sin(azi) * cos(ele)
+    return (x, y)
